# Ludovico

An opinionated DataFrame-to-TeX table generator.

## What's this?

Ludovico is a small tool to generate valid TeX tables from data contained within Pandas DataFrames. It's a personal tool that I'm developing to assist myself in the process of generating tables for my Computer Science undergraduate senior thesis, which requires making a considerable amount of tables from data that is currently handled as dataframes.
